"""
Qdrant Vector Database Integration

Provides persona registry and semantic search capabilities.
"""

from empirica.core.qdrant.persona_registry import PersonaRegistry

__all__ = ["PersonaRegistry"]
